==> openshift-model-4.13.0-sources.jar: annotations/io/fabric8/openshift/api/model/ProjectStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ProjectStatusBuilder extends ProjectStatusFluentImpl<ProjectStatusBuilder> implements VisitableBuilder<ProjectStatus,ProjectStatusBuilder> {

    ProjectStatusFluent<?> fluent;
    Boolean validationEnabled;

    public ProjectStatusBuilder() { 
        this(true);
    }


    public ProjectStatusBuilder(Boolean validationEnabled) { 
        this(new ProjectStatus(), validationEnabled);
    }


    public ProjectStatusBuilder(ProjectStatusFluent<?> fluent) { 
        this(fluent, true);
    }


    public ProjectStatusBuilder(ProjectStatusFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new ProjectStatus(), validationEnabled);
    }


    public ProjectStatusBuilder(ProjectStatusFluent<?> fluent,ProjectStatus instance) { 
        this(fluent, instance, true);
    }


    public ProjectStatusBuilder(ProjectStatusFluent<?> fluent,ProjectStatus instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withConditions(instance.getConditions()); 
        fluent.withPhase(instance.getPhase()); 
        this.validationEnabled = validationEnabled; 
    }


    public ProjectStatusBuilder(ProjectStatus instance) { 
        this(instance,true);
    }


    public ProjectStatusBuilder(ProjectStatus instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withConditions(instance.getConditions()); 
        this.withPhase(instance.getPhase()); 
        this.validationEnabled = validationEnabled; 
    }


    public ProjectStatus build() {
        ProjectStatus buildable = new ProjectStatus(fluent.getConditions(),fluent.getPhase());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ProjectStatusBuilder that = (ProjectStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/ProjectStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ProjectStatusBuilder extends ProjectStatusFluentImpl<ProjectStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<ProjectStatus,ProjectStatusBuilder> {

    ProjectStatusFluent<?> fluent;
    Boolean validationEnabled;

    public ProjectStatusBuilder() {
        this(true);
    }

    public ProjectStatusBuilder(Boolean validationEnabled) {
        this(new ProjectStatus(), validationEnabled);
    }

    public ProjectStatusBuilder(ProjectStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public ProjectStatusBuilder(ProjectStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ProjectStatus(), validationEnabled);
    }

    public ProjectStatusBuilder(ProjectStatusFluent<?> fluent,ProjectStatus instance) {
        this(fluent, instance, true);
    }

    public ProjectStatusBuilder(ProjectStatusFluent<?> fluent,ProjectStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withConditions(instance.getConditions()); 
        fluent.withPhase(instance.getPhase()); 
        this.validationEnabled = validationEnabled; 
    }

    public ProjectStatusBuilder(ProjectStatus instance) {
        this(instance,true);
    }

    public ProjectStatusBuilder(ProjectStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withConditions(instance.getConditions()); 
        this.withPhase(instance.getPhase()); 
        this.validationEnabled = validationEnabled; 
    }

    public ProjectStatus build() {
        ProjectStatus buildable = new ProjectStatus(fluent.getConditions(),fluent.getPhase());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ProjectStatusBuilder that = (ProjectStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
